@@ -1,7 +1,7 @@
 package MooseX::MethodAttributes::Role::AttrContainer;
-our $VERSION = '0.16_01';
+our $VERSION = '0.01';
 
-# ABSTRACT: capture code attributes in the class' metaclass
+# ABSTRACT: Capture code attributes in the class' metaclass
 
 use Moose::Role;
 use Moose::Util qw/find_meta/;
@@ -18,16 +18,13 @@ sub MODIFY_CODE_ATTRIBUTES {
 1;
 
 __END__
-
-=pod
-
 =head1 NAME
 
-MooseX::MethodAttributes::Role::AttrContainer - capture code attributes in the class' metaclass
+MooseX::MethodAttributes::Role::AttrContainer - Capture code attributes in the class' metaclass
 
 =head1 VERSION
 
-version 0.16_01
+version 0.01
 
 =head1 METHODS
 
@@ -37,20 +34,14 @@ Accepts a list of attributes for a coderef and stores it the class' metaclass.
 
 See L<attributes>.
 
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
