@@ -1,5 +1,5 @@
 package MooseX::MethodAttributes::Role::Meta::Method;
-our $VERSION = '0.16_01';
+our $VERSION = '0.01';
 
 # ABSTRACT: metamethod role allowing code attribute introspection
 
@@ -17,27 +17,19 @@ has attributes => (
 
 sub _build_attributes {
     my ($self) = @_;
-    return $self->associated_metaclass->get_method_attributes($self->_get_attributed_coderef);
-}
-
-sub _get_attributed_coderef {
-    my ($self) = @_;
-    return $self->body;
+    return $self->associated_metaclass->get_method_attributes($self->body);
 }
 
 1;
 
 __END__
-
-=pod
-
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method - metamethod role allowing code attribute introspection
 
 =head1 VERSION
 
-version 0.16_01
+version 0.01
 
 =head1 ATTRIBUTES
 
@@ -54,20 +46,14 @@ Gets the list of code attributes of the method represented by this meta method.
 Builds the value of the C<attributes> attribute based on the attributes
 captured in the associated meta class.
 
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
