@@ -1,5 +1,5 @@
 package TestClass;
-our $VERSION = '0.16_01';
+our $VERSION = '0.01';
 
 
 use Moose;
@@ -7,12 +7,8 @@ use MooseX::MethodAttributes;
 
 sub foo : SomeAttribute AnotherAttribute('with argument') {}
 
-sub bar : SomeAttribute {}
-
-after foo => sub {};
-
 package SubClass;
-our $VERSION = '0.16_01';
+our $VERSION = '0.01';
 
 
 use Moose;
@@ -22,6 +18,4 @@ extends qw/TestClass/;
 
 sub foo : Attributes Attributes Attributes {}
 
-sub bar {}  # no attribute!
-
 1;
